<?php
/**
 * The header for our theme
 */

if (!defined('ABSPATH')) {
    exit;
}

// Get basic settings
$basic_settings = get_option('basic_settings', array());
$page_layout = $basic_settings['page_layout'] ?? 'container';
$container_width = $basic_settings['container_width'] ?? '1140';

// Set site width style
$site_style = '';
if ($page_layout === 'container') {
    $site_style = 'max-width: ' . $container_width . 'px; margin: 0 auto;';
} else {
    $site_style = 'max-width: 100%;';
}
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="https://gmpg.org/xfn/11">
    <style>
        /* Critical CSS */
        body { margin: 0; padding: 0; }
        .site { display: flex; flex-direction: column; min-height: 100vh; }
        .site-content { flex: 1; }
        
        /* Loading Screen Styles */
        #loading-screen {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: #fff;
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 9999;
            transition: opacity 0.5s ease-out, visibility 0.5s ease-out;
        }
        
        #loading-screen.hidden {
            opacity: 0;
            visibility: hidden;
        }
        
        .loader {
            border: 5px solid #f3f3f3;
            border-top: 5px solid #3498db;
            border-radius: 50%;
            width: 50px;
            height: 50px;
            animation: spin 1s linear infinite;
        }
        
        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
    </style>
    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>

<!-- Loading Screen -->
<div id="loading-screen">
    <div class="loader"></div>
</div>

<script>
    // Hide loading screen when everything is loaded
    window.addEventListener('load', function() {
        var loadingScreen = document.getElementById('loading-screen');
        if (loadingScreen) {
            loadingScreen.classList.add('hidden');
            
            // Remove from DOM after animation completes
            setTimeout(function() {
                loadingScreen.remove();
            }, 500);
        }
    });
    
    // Fallback in case load event doesn't fire
    setTimeout(function() {
        var loadingScreen = document.getElementById('loading-screen');
        if (loadingScreen) {
            loadingScreen.classList.add('hidden');
            setTimeout(function() {
                loadingScreen.remove();
            }, 500);
        }
    }, 5000); // 5 seconds max wait time
</script>

<div id="page" class="site" style="<?php echo esc_attr($site_style); ?>">
    <a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e('Skip to content', 'mohtavanegar'); ?></a>

    <header id="masthead" class="site-header<?php echo get_option('header_fixed') ? ' fixed-top' : ''; ?>">
        <?php
        // Get header template
        $header_template = get_option('header_template');
        $header_type = get_option('header_type', 'default');
        
        if ($header_template) {
            echo '<div class="site-header type-' . esc_attr($header_type) . '">';
            echo do_shortcode('[elementor-template id="' . $header_template . '"]');
            echo '</div>';
        } else {
            // Default header content
            ?>
            <div class="site-branding">
                <?php
                if (has_custom_logo()) :
                    the_custom_logo();
                else :
                    ?>
                    <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>" rel="home"><?php bloginfo('name'); ?></a></h1>
                    <?php
                    $description = get_bloginfo('description', 'display');
                    if ($description || is_customize_preview()) :
                        ?>
                        <p class="site-description"><?php echo $description; ?></p>
                    <?php endif; ?>
                <?php endif; ?>
            </div>

            <nav id="site-navigation" class="main-navigation">
                <?php
                wp_nav_menu(array(
                    'theme_location' => 'menu-1',
                    'menu_id'        => 'primary-menu',
                ));
                ?>
            </nav>
            <?php
        }
        ?>
    </header>

    <div id="content" class="site-content"> 