jQuery(document).ready(function($) {
    // Create answer modal if it doesn't exist
    if ($('#qa-answer-modal').length === 0) {
        $('body').append(`
            <div id="qa-answer-modal" class="qa-answer-modal">
                <div class="qa-answer-modal-content">
                    <span class="qa-answer-modal-close">&times;</span>
                    <h2>پاسخ به پرسش</h2>
                    <div id="qa-question-content"></div>
                    <div class="qa-answer-form-group">
                        <label for="qa-answer-text">پاسخ:</label>
                        <textarea id="qa-answer-text" class="qa-answer-textarea"></textarea>
                    </div>
                    <button id="qa-answer-submit" class="qa-answer-submit">ثبت پاسخ</button>
                </div>
            </div>
        `);
    }
    
    // Tab navigation
    $('.nav-tab-wrapper a').on('click', function(e) {
        e.preventDefault();
        
        // Hide all tab contents
        $('.tab-content').hide();
        
        // Remove active class from all tabs
        $('.nav-tab').removeClass('nav-tab-active');
        
        // Show the selected tab content
        $($(this).attr('href')).show();
        
        // Add active class to the clicked tab
        $(this).addClass('nav-tab-active');
    });
    
    // Approve comment
    $('.approve-comment').on('click', function() {
        var commentId = $(this).data('id');
        var row = $('#comment-' + commentId);
        
        if (confirm('آیا از تایید این نظر اطمینان دارید؟')) {
            $.ajax({
                url: qaAdminData.ajaxUrl,
                type: 'POST',
                data: {
                    action: 'approve_qa_comment',
                    comment_id: commentId,
                    nonce: qaAdminData.nonce
                },
                success: function(response) {
                    if (response.success) {
                        row.fadeOut(300, function() {
                            $(this).remove();
                            
                            // Check if there are no more pending comments
                            if ($('#pending-comments tbody tr').length === 0) {
                                $('#pending-comments tbody').html('<tr><td colspan="5">هیچ نظری در انتظار تایید وجود ندارد.</td></tr>');
                            }
                            
                            // Reload the page to update both tabs
                            location.reload();
                        });
                    } else {
                        alert('خطا: ' + response.data);
                    }
                },
                error: function() {
                    alert('خطا در ارتباط با سرور. لطفا دوباره تلاش کنید.');
                }
            });
        }
    });
    
    // Delete comment
    $('.delete-comment').on('click', function() {
        var commentId = $(this).data('id');
        var row = $('#comment-' + commentId);
        
        if (confirm('آیا از حذف این نظر اطمینان دارید؟ این عمل غیرقابل بازگشت است.')) {
            $.ajax({
                url: qaAdminData.ajaxUrl,
                type: 'POST',
                data: {
                    action: 'delete_qa_comment',
                    comment_id: commentId,
                    nonce: qaAdminData.nonce
                },
                success: function(response) {
                    if (response.success) {
                        row.fadeOut(300, function() {
                            $(this).remove();
                            
                            // Check if there are no more comments in the current tab
                            var currentTab = $('.nav-tab-active').attr('href');
                            if ($(currentTab + ' tbody tr').length === 0) {
                                if (currentTab === '#pending-comments') {
                                    $(currentTab + ' tbody').html('<tr><td colspan="6">هیچ نظری در انتظار تایید وجود ندارد.</td></tr>');
                                } else {
                                    $(currentTab + ' tbody').html('<tr><td colspan="7">هیچ نظر تایید شده‌ای وجود ندارد.</td></tr>');
                                }
                            }
                        });
                    } else {
                        alert('خطا: ' + response.data);
                    }
                },
                error: function() {
                    alert('خطا در ارتباط با سرور. لطفا دوباره تلاش کنید.');
                }
            });
        }
    });
    
    // Answer comment
    $('.answer-comment').on('click', function() {
        var commentId = $(this).data('id');
        var row = $('#comment-' + commentId);
        var questionText = row.find('td:nth-child(4)').text(); // Get question text
        var currentAnswer = row.find('td:nth-child(5)').html(); // Get current answer if exists
        
        // Set question and answer in modal
        $('#qa-question-content').html('<p><strong>پرسش:</strong> ' + questionText + '</p>');
        $('#qa-answer-text').val(currentAnswer ? currentAnswer.replace(/<br\/?>/g, '\n') : '');
        
        // Store comment ID for submission
        $('#qa-answer-submit').data('id', commentId);
        
        // Show modal
        $('#qa-answer-modal').fadeIn(300);
    });
    
    // Close modal
    $('.qa-answer-modal-close').on('click', function() {
        $('#qa-answer-modal').fadeOut(300);
    });
    
    // Close modal when clicking outside
    $(window).on('click', function(e) {
        if ($(e.target).is('.qa-answer-modal')) {
            $('.qa-answer-modal').fadeOut(300);
        }
    });
    
    // Submit answer
    $('#qa-answer-submit').on('click', function() {
        var commentId = $(this).data('id');
        var answerText = $('#qa-answer-text').val();
        
        $.ajax({
            url: qaAdminData.ajaxUrl,
            type: 'POST',
            data: {
                action: 'save_qa_answer',
                comment_id: commentId,
                answer: answerText,
                nonce: qaAdminData.nonce
            },
            beforeSend: function() {
                $('#qa-answer-submit').prop('disabled', true).text('در حال ذخیره...');
            },
            success: function(response) {
                if (response.success) {
                    // Update answer in table
                    var formattedAnswer = answerText.replace(/\n/g, '<br>');
                    $('#comment-' + commentId + ' td:nth-child(5)').html(formattedAnswer);
                    
                    // Close modal
                    $('#qa-answer-modal').fadeOut(300);
                    
                    // Show success message
                    alert('پاسخ با موفقیت ذخیره شد.');
                } else {
                    alert('خطا: ' + response.data);
                }
                
                // Re-enable submit button
                $('#qa-answer-submit').prop('disabled', false).text('ثبت پاسخ');
            },
            error: function() {
                alert('خطا در ارتباط با سرور. لطفا دوباره تلاش کنید.');
                $('#qa-answer-submit').prop('disabled', false).text('ثبت پاسخ');
            }
        });
    });
    
    // Save answer in post edit screen
    $('#post input[name="save"]').on('click', function() {
        var answer = $('#qa_answer').val();
        var postId = $('#post_ID').val();
        
        // Store the answer in a hidden field to be saved with the post
        if (!$('#_qa_answer_hidden').length) {
            $('<input>').attr({
                type: 'hidden',
                id: '_qa_answer_hidden',
                name: '_qa_answer',
                value: answer
            }).appendTo('#post');
        } else {
            $('#_qa_answer_hidden').val(answer);
        }
    });
});
