jQuery(document).ready(function($) {
    // Handle form submission
    $('#qa-submission-form').on('submit', function(e) {
        e.preventDefault();
        
        // Get form data
        var name = $('#qa-name').val();
        var email = $('#qa-email').val();
        var mobile = $('#qa-mobile').val();
        var question = $('#qa-question').val();
        
        // Validate form data
        if (!name || !question) {
            showMessage('error', 'لطفا نام و پرسش خود را وارد کنید.');
            return;
        }
        
        // Validate email if provided
        if (email && !isValidEmail(email)) {
            showMessage('error', 'لطفا یک ایمیل معتبر وارد کنید.');
            return;
        }
        
        // Validate mobile if provided
        if (mobile && !isValidMobile(mobile)) {
            showMessage('error', 'لطفا یک شماره موبایل معتبر وارد کنید.');
            return;
        }
        
        // Submit form via AJAX
        $.ajax({
            url: qaFrontendData.ajaxUrl,
            type: 'POST',
            data: {
                action: 'submit_qa_comment',
                name: name,
                email: email,
                mobile: mobile,
                question: question,
                nonce: qaFrontendData.nonce
            },
            beforeSend: function() {
                $('.qa-submit-button').prop('disabled', true).text('در حال ارسال...');
            },
            success: function(response) {
                if (response.success) {
                    // Show success message
                    showMessage('success', response.data);
                    
                    // Reset form
                    $('#qa-submission-form')[0].reset();
                } else {
                    // Show error message
                    showMessage('error', response.data);
                }
                
                // Re-enable submit button
                $('.qa-submit-button').prop('disabled', false).text('ارسال پرسش');
            },
            error: function() {
                // Show error message
                showMessage('error', 'خطا در ارتباط با سرور. لطفا دوباره تلاش کنید.');
                
                // Re-enable submit button
                $('.qa-submit-button').prop('disabled', false).text('ارسال پرسش');
            }
        });
    });
    
    // Function to show messages
    function showMessage(type, message) {
        var messageElement = $('#qa-form-message');
        
        // Set message content and class
        messageElement.html(message).removeClass('success error').addClass(type);
        
        // Show message
        messageElement.fadeIn(300);
        
        // Hide message after 5 seconds
        setTimeout(function() {
            messageElement.fadeOut(300);
        }, 5000);
    }
    
    // Function to validate email
    function isValidEmail(email) {
        var emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
        return emailRegex.test(email);
    }
    
    // Function to validate mobile number (Iranian format)
    function isValidMobile(mobile) {
        var mobileRegex = /^09[0-9]{9}$/;
        return mobileRegex.test(mobile);
    }
});
