<?php
if (!defined('ABSPATH')) {
    exit;
}

// Register Services Post Type
function mohtavanegar_register_services_post_type() {
    $labels = array(
        'name'                  => _x('خدمات', 'Post type general name', 'mohtavanegar'),
        'singular_name'         => _x('خدمات', 'Post type singular name', 'mohtavanegar'),
        'menu_name'            => _x('خدمات', 'Admin Menu text', 'mohtavanegar'),
        'name_admin_bar'       => _x('خدمات', 'Add New on Toolbar', 'mohtavanegar'),
        'add_new'              => __('افزودن جدید', 'mohtavanegar'),
        'add_new_item'         => __('افزودن خدمات جدید', 'mohtavanegar'),
        'new_item'             => __('خدمات جدید', 'mohtavanegar'),
        'edit_item'            => __('ویرایش خدمات', 'mohtavanegar'),
        'view_item'            => __('مشاهده خدمات', 'mohtavanegar'),
        'all_items'            => __('همه خدمات', 'mohtavanegar'),
        'search_items'         => __('جستجوی خدمات', 'mohtavanegar'),
        'not_found'            => __('هیچ خدمتی یافت نشد.', 'mohtavanegar'),
        'not_found_in_trash'   => __('هیچ خدمتی در سطل زباله یافت نشد.', 'mohtavanegar'),
        'featured_image'       => _x('تصویر شاخص خدمات', 'Overrides the "Featured Image" phrase', 'mohtavanegar'),
        'set_featured_image'   => _x('تنظیم تصویر شاخص', 'Overrides the "Set featured image" phrase', 'mohtavanegar'),
        'remove_featured_image'=> _x('حذف تصویر شاخص', 'Overrides the "Remove featured image" phrase', 'mohtavanegar'),
        'use_featured_image'   => _x('استفاده به عنوان تصویر شاخص', 'Overrides the "Use as featured image" phrase', 'mohtavanegar'),
        'archives'             => _x('آرشیو خدمات', 'The post type archive label used in nav menus', 'mohtavanegar'),
        'insert_into_item'     => _x('درج در خدمات', 'Overrides the "Insert into post" phrase', 'mohtavanegar'),
        'uploaded_to_this_item'=> _x('آپلود شده در این خدمات', 'Overrides the "Uploaded to this post" phrase', 'mohtavanegar'),
        'filter_items_list'    => _x('فیلتر لیست خدمات', 'Screen reader text for the filter links heading', 'mohtavanegar'),
        'items_list_navigation'=> _x('ناوبری لیست خدمات', 'Screen reader text for the pagination heading', 'mohtavanegar'),
        'items_list'           => _x('لیست خدمات', 'Screen reader text for the items list heading', 'mohtavanegar'),
    );

    $args = array(
        'labels'             => $labels,
        'public'             => true,
        'publicly_queryable' => true,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'query_var'          => true,
        'rewrite'            => array('slug' => 'services'),
        'capability_type'    => 'post',
        'has_archive'        => true,
        'hierarchical'       => false,
        'menu_position'      => 5,
        'menu_icon'          => 'dashicons-clipboard',
        'supports'           => array('title', 'editor', 'thumbnail', 'excerpt', 'custom-fields'),
        'show_in_rest'       => true,
    );

    register_post_type('services', $args);
}
add_action('init', 'mohtavanegar_register_services_post_type');

// Register Services Category Taxonomy
function mohtavanegar_register_services_taxonomy() {
    $labels = array(
        'name'              => _x('دسته‌بندی خدمات', 'taxonomy general name', 'mohtavanegar'),
        'singular_name'     => _x('دسته‌بندی خدمات', 'taxonomy singular name', 'mohtavanegar'),
        'search_items'      => __('جستجوی دسته‌بندی‌ها', 'mohtavanegar'),
        'all_items'         => __('همه دسته‌بندی‌ها', 'mohtavanegar'),
        'parent_item'       => __('دسته‌بندی والد', 'mohtavanegar'),
        'parent_item_colon' => __('دسته‌بندی والد:', 'mohtavanegar'),
        'edit_item'         => __('ویرایش دسته‌بندی', 'mohtavanegar'),
        'update_item'       => __('بروزرسانی دسته‌بندی', 'mohtavanegar'),
        'add_new_item'      => __('افزودن دسته‌بندی جدید', 'mohtavanegar'),
        'new_item_name'     => __('نام دسته‌بندی جدید', 'mohtavanegar'),
        'menu_name'         => __('دسته‌بندی‌ها', 'mohtavanegar'),
    );

    $args = array(
        'hierarchical'      => true,
        'labels'            => $labels,
        'show_ui'           => true,
        'show_admin_column' => true,
        'query_var'         => true,
        'rewrite'           => array('slug' => 'services-category'),
        'show_in_rest'      => true,
    );

    register_taxonomy('services_category', array('services'), $args);
}
add_action('init', 'mohtavanegar_register_services_taxonomy');

// Add custom meta boxes for services
function mohtavanegar_add_services_meta_boxes() {
    add_meta_box(
        'services_details',
        __('جزئیات خدمات', 'mohtavanegar'),
        'mohtavanegar_services_meta_box_callback',
        'services',
        'normal',
        'high'
    );
}
add_action('add_meta_boxes', 'mohtavanegar_add_services_meta_boxes');

// Meta box callback function
function mohtavanegar_services_meta_box_callback($post) {
    wp_nonce_field('mohtavanegar_save_services_meta', 'mohtavanegar_services_meta_nonce');

    $service_icon = get_post_meta($post->ID, '_service_icon', true);
    $service_price = get_post_meta($post->ID, '_service_price', true);
    $service_duration = get_post_meta($post->ID, '_service_duration', true);
    ?>
    <div class="mohtavanegar-meta-box">
        <p>
            <label for="service_icon"><?php _e('آیکون خدمات:', 'mohtavanegar'); ?></label>
            <input type="text" id="service_icon" name="service_icon" value="<?php echo esc_attr($service_icon); ?>" class="widefat">
        </p>
        <p>
            <label for="service_price"><?php _e('قیمت:', 'mohtavanegar'); ?></label>
            <input type="text" id="service_price" name="service_price" value="<?php echo esc_attr($service_price); ?>" class="widefat">
        </p>
        <p>
            <label for="service_duration"><?php _e('مدت زمان:', 'mohtavanegar'); ?></label>
            <input type="text" id="service_duration" name="service_duration" value="<?php echo esc_attr($service_duration); ?>" class="widefat">
        </p>
    </div>
    <?php
}

// Save meta box data
function mohtavanegar_save_services_meta($post_id) {
    if (!isset($_POST['mohtavanegar_services_meta_nonce'])) {
        return;
    }

    if (!wp_verify_nonce($_POST['mohtavanegar_services_meta_nonce'], 'mohtavanegar_save_services_meta')) {
        return;
    }

    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }

    if (!current_user_can('edit_post', $post_id)) {
        return;
    }

    if (isset($_POST['service_icon'])) {
        update_post_meta($post_id, '_service_icon', sanitize_text_field($_POST['service_icon']));
    }

    if (isset($_POST['service_price'])) {
        update_post_meta($post_id, '_service_price', sanitize_text_field($_POST['service_price']));
    }

    if (isset($_POST['service_duration'])) {
        update_post_meta($post_id, '_service_duration', sanitize_text_field($_POST['service_duration']));
    }
}
add_action('save_post_services', 'mohtavanegar_save_services_meta'); 