<?php
if (!defined('ABSPATH')) {
    exit;
}

class Mohtavanegar_Elementor_Widgets {
    private static $_instance = null;

    public static function instance() {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    public function __construct() {
        // Support both older and newer versions of Elementor
        if (version_compare(ELEMENTOR_VERSION, '3.5.0', '<')) {
            // For Elementor < 3.5.0
            add_action('elementor/widgets/widgets_registered', [$this, 'register_widgets']);
        } else {
            // For Elementor >= 3.5.0
            add_action('elementor/widgets/register', [$this, 'register_widgets']);
        }
        
        // Categories registration also has a newer hook
        if (version_compare(ELEMENTOR_VERSION, '3.0.0', '<')) {
            add_action('elementor/elements/categories_registered', [$this, 'add_widget_categories']);
        } else {
            add_action('elementor/elements/categories_register', [$this, 'add_widget_categories']);
        }
    }

    public function register_widgets($widgets_manager) {
        $this->register_mohtavanegar_elementor_widgets($widgets_manager);
    }

    public function register_mohtavanegar_elementor_widgets($widgets_manager) {
        // Enqueue widget styles
        wp_enqueue_style(
            'taxonomy-display-widget',
            get_template_directory_uri() . '/assets/css/taxonomy-display-widget.css',
            array(),
            '1.0.0'
        );

        // Enqueue widget styles and scripts
        wp_register_style(
            'contact-us-widget',
            get_template_directory_uri() . '/assets/css/contact-us-widget.css',
            [],
            '1.0.0'
        );
        
        wp_register_script(
            'contact-us-widget',
            get_template_directory_uri() . '/assets/js/contact-us-widget.js',
            ['jquery'],
            '1.0.0',
            true
        );
        
        // Register Appointment Websites Widget assets
        wp_register_style(
            'appointment-websites-widget',
            get_template_directory_uri() . '/assets/css/appointment-websites-widget.css',
            [],
            '1.0.0'
        );
        
        wp_register_script(
            'appointment-websites-widget',
            get_template_directory_uri() . '/assets/js/appointment-websites-widget.js',
            ['jquery', 'imagesloaded'],
            '1.0.0',
            true
        );

        // Register widget styles and scripts
 
        if (!wp_style_is('posts-display-widget', 'registered')) {
            wp_register_style(
                'posts-display-widget',
                get_template_directory_uri() . '/assets/css/posts-display-widget.css',
                ['swiper'],
                '1.5.0'
            );
        }
 
        if (!wp_script_is('posts-display-widget', 'registered')) {
            wp_register_script(
                'posts-display-widget',
                get_template_directory_uri() . '/assets/js/posts-display-widget.js',
                ['jquery', 'swiper'],
                '1.5.0',
                true
            );
            
            // Localize script for RTL support
            wp_localize_script('posts-display-widget', 'mohtavanegarPostsVars', [
                'rtl' => is_rtl()
            ]);
        }
        
        // Enqueue the scripts and styles
        wp_enqueue_style('swiper');
        wp_enqueue_style('posts-display-widget');
        wp_enqueue_script('swiper');
        wp_enqueue_script('posts-display-widget');

        // Include widget files first
        require_once(__DIR__ . '/services-list-widget.php');
        require_once(__DIR__ . '/taxonomy-display-widget.php');
        require_once(__DIR__ . '/before-after-widget.php');
        require_once(__DIR__ . '/working-hours-widget.php');
        require_once(__DIR__ . '/qa-widget.php');
        require_once(__DIR__ . '/contact-us-widget.php');
        require_once(__DIR__ . '/appointment-websites-widget.php');
        
        // Include Posts Display Widget
        $posts_widget_file = __DIR__ . '/posts-display-widget.php';
        if (file_exists($posts_widget_file)) {
            require_once($posts_widget_file);
        } else {
            error_log('Posts Display Widget file not found at: ' . $posts_widget_file);
        }
        
        // Register widgets
        $widgets_manager->register_widget_type(new Mohtavanegar_Services_List_Widget());
        $widgets_manager->register_widget_type(new \Elementor\Mohtavanegar_Before_After_Widget());
        $widgets_manager->register_widget_type(new Mohtavanegar_Working_Hours_Widget());
        $widgets_manager->register_widget_type(new Mohtavanegar_Taxonomy_Display_Widget());
        $widgets_manager->register_widget_type(new Mohtavanegar_QA_Widget());
        
        // Check if the Posts Display Widget class exists before instantiating
        if (class_exists('Mohtavanegar_Posts_Display_Widget')) {
            $widgets_manager->register_widget_type(new Mohtavanegar_Posts_Display_Widget());
        } else {
            error_log('Mohtavanegar_Posts_Display_Widget class not found');
        }
    }

    public function add_widget_categories($elements_manager) {
        $elements_manager->add_category(
            'mohtavanegar',
            [
                'title' => esc_html__('محتوا نگار', 'mohtavanegar'),
                'icon' => 'fa fa-plug',
            ]
        );
    }
}

// Initialize the widgets
Mohtavanegar_Elementor_Widgets::instance();