<?php
if (!defined('ABSPATH')) {
    exit;
}

class Mohtavanegar_Posts_Display_Widget extends \Elementor\Widget_Base {
    public function get_name() {
        return 'mohtavanegar_posts_display';
    }

    public function get_title() {
        return __('نمایش پست‌ها', 'mohtavanegar');
    }

    public function get_icon() {
        return 'eicon-posts-grid';
    }

    public function get_categories() {
        return ['mohtavanegar'];
    }

    protected function register_controls() {
        // Content Tab
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('محتوا', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        // Post Type
        $post_types = get_post_types(['public' => true], 'objects');
        $post_type_options = [];
        foreach ($post_types as $post_type) {
            $post_type_options[$post_type->name] = $post_type->label;
        }

        $this->add_control(
            'post_type',
            [
                'label' => __('نوع پست', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'post',
                'options' => $post_type_options,
            ]
        );

        // Display Type
        $this->add_control(
            'display_type',
            [
                'label' => __('نوع نمایش', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'grid',
                'options' => [
                    'grid' => __('شبکه‌ای', 'mohtavanegar'),
                    'carousel' => __('کروسل', 'mohtavanegar'),
                    'list' => __('لیستی', 'mohtavanegar'),
                ],
                'frontend_available' => true,
            ]
        );

        // Image Settings
        $this->add_control(
            'show_thumbnail',
            [
                'label' => __('نمایش تصویر شاخص', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('نمایش', 'mohtavanegar'),
                'label_off' => __('مخفی', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'yes',
                'separator' => 'before',
            ]
        );
        
        // Add custom image size for grid view
        add_image_size('mohtavanegar_grid_300x260', 300, 260, true);
        
        $this->add_control(
            'image_size',
            [
                'label' => __('اندازه تصویر شاخص', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'thumbnail' => __('تصویر بند انگشتی', 'mohtavanegar'),
                    'medium' => __('متوسط', 'mohtavanegar'),
                    'large' => __('بزرگ', 'mohtavanegar'),
                    'full' => __('سایز کامل', 'mohtavanegar'),
                    'mohtavanegar_grid_300x260' => __('شبکه 300x260 (برش خورده)', 'mohtavanegar'),
                ],
                'default' => 'mohtavanegar_grid_300x260',
                'condition' => [
                    'show_thumbnail' => 'yes',
                ],
            ]
        );
        
        $this->add_control(
            'image_size_custom',
            [
                'label' => __('سایز سفارشی تصویر', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'description' => __('عرض و ارتفاع تصویر را به پیکسل وارد کنید. برای فعال کردن برش خودکار، هر دو مقدار را وارد کنید.', 'mohtavanegar'),
                'condition' => [
                    'show_thumbnail' => 'yes',
                    'image_size' => 'custom',
                ],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-post-thumbnail img' => 'width: {{WIDTH}}{{UNIT}}; height: {{HEIGHT}}{{UNIT}}; object-fit: cover;',
                ],
            ]
        );

        $this->end_controls_section(); // End content_section

        // Carousel Settings Section
        $this->start_controls_section(
            'carousel_section',
            [
                'label' => __('تنظیمات کروسل', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'display_type' => 'carousel',
                ],
            ]
        );

        // Show Arrows
        $this->add_control(
            'show_arrows',
            [
                'label' => __('نمایش فلش‌های ناوبری', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('نمایش', 'mohtavanegar'),
                'label_off' => __('مخفی', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        // Arrow Style
        $this->add_control(
            'arrow_style',
            [
                'label' => __('استایل فلش‌ها', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'default',
                'options' => [
                    'default' => __('پیش‌فرض', 'mohtavanegar'),
                    'circle' => __('دایره', 'mohtavanegar'),
                    'square' => __('مربع', 'mohtavanegar'),
                    'angle' => __('زاویه‌دار', 'mohtavanegar'),
                ],
                'condition' => [
                    'show_arrows' => 'yes',
                ],
            ]
        );

        // Show Dots
        $this->add_control(
            'show_dots',
            [
                'label' => __('نمایش نقاط ناوبری', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('نمایش', 'mohtavanegar'),
                'label_off' => __('مخفی', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        // Autoplay
        $this->add_control(
            'autoplay',
            [
                'label' => __('پخش خودکار', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('روشن', 'mohtavanegar'),
                'label_off' => __('خاموش', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        // Autoplay Speed
        $this->add_control(
            'autoplay_speed',
            [
                'label' => __('سرعت پخش خودکار (میلی‌ثانیه)', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 3000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        // Loop
        $this->add_control(
            'infinite_loop',
            [
                'label' => __('حلقه بی‌نهایت', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('روشن', 'mohtavanegar'),
                'label_off' => __('خاموش', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        // Pause on Hover
        $this->add_control(
            'pause_on_hover',
            [
                'label' => __('توقف در هنگام هاور', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('روشن', 'mohtavanegar'),
                'label_off' => __('خاموش', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'image_spacing',
            [
                'label' => __('Image Spacing', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
            ]
        );

        $this->end_controls_section(); // End Carousel Settings Section
        
        // Content Display Section
        $this->start_controls_section(
            'content_display_section',
            [
                'label' => __('نمایش محتوا', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        // Posts Per Page
        $this->add_control(
            'posts_per_page',
            [
                'label' => __('تعداد پست‌های قابل نمایش', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 6,
                'min' => 1,
                'max' => 50,
            ]
        );

        // Show Excerpt
        $this->add_control(
            'show_excerpt',
            [
                'label' => __('نمایش خلاصه مطلب', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('بله', 'mohtavanegar'),
                'label_off' => __('خیر', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        // Show Meta
        $this->add_control(
            'show_meta',
            [
                'label' => __('نمایش اطلاعات متا (نویسنده، تاریخ)', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('بله', 'mohtavanegar'),
                'label_off' => __('خیر', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        // Show Read More
        $this->add_control(
            'show_read_more',
            [
                'label' => __('نمایش دکمه ادامه مطلب', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('بله', 'mohtavanegar'),
                'label_off' => __('خیر', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->end_controls_section(); // End Content Display Section

        // Style Tab - General
        $this->start_controls_section(
            'general_style_section',
            [
                'label' => __('استایل عمومی', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        // Image Style
        $this->add_control(
            'image_style_heading',
            [
                'label' => __('تصویر شاخص', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'show_thumbnail' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'image_ratio',
            [
                'label' => __('نسبت تصویر', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'square',
                'options' => [
                    'original' => __('اصلی', 'mohtavanegar'),
                    'square' => __('مربع (1:1)', 'mohtavanegar'),
                    'rectangle' => __('مستطیل (4:3)', 'mohtavanegar'),
                ],
                'prefix_class' => 'mohtavanegar-image-ratio-',
                'condition' => [
                    'show_thumbnail' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'image_spacing',
            [
                'label' => __('فاصله تصویر', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em'],
                'default' => [
                    'size' => 15,
                    'unit' => 'px',
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-post-thumbnail' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_thumbnail' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'image_border_radius',
            [
                'label' => __('گردی گوشه‌ها', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-post-thumbnail' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}; overflow: hidden;',
                ],
                'condition' => [
                    'show_thumbnail' => 'yes',
                ],
            ]
        );

        // Layout Spacing
        $this->add_control(
            'layout_spacing_heading',
            [
                'label' => __('فاصله‌بندی', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'column_gap',
            [
                'label' => __('فاصله بین ستون‌ها', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em'],
                'default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                   // '{{WRAPPER}} .mohtavanegar-posts-grid' => 'margin-right: -{{SIZE}}{{UNIT}}; margin-left: -{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mohtavanegar-posts-grid .mohtavanegar-post-item' => 'padding-right: {{SIZE}}{{UNIT}}; padding-left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mohtavanegar-carousel .swiper' => 'padding-right: {{SIZE}}{{UNIT}}; padding-left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'row_gap',
            [
                'label' => __('فاصله بین سطرها', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em'],
                'default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-posts-grid' => 'margin-bottom: -{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mohtavanegar-post-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mohtavanegar-carousel .swiper-slide' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __('فاصله محتوا', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-post-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        // Title Style
        $this->add_control(
            'title_style_heading',
            [
                'label' => __('عنوان', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __('تایپوگرافی عنوان', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .mohtavanegar-post-title',
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __('رنگ عنوان', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-post-title a' => 'color: {{VALUE}}',
                ],
            ]
        );

        // Meta Style
        $this->add_control(
            'meta_style_heading',
            [
                'label' => __('اطلاعات متا', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'show_meta' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'meta_color',
            [
                'label' => __('رنگ متا', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-post-meta' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_meta' => 'yes',
                ],
            ]
        );

        // Read More Button Style
        $this->add_control(
            'read_more_style_heading',
            [
                'label' => __('دکمه ادامه مطلب', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        // Text Color
        $this->start_controls_tabs('read_more_style_tabs');

        // Normal State
        $this->start_controls_tab(
            'read_more_normal_tab',
            [
                'label' => __('عادی', 'mohtavanegar'),
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'read_more_color',
            [
                'label' => __('رنگ متن', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-read-more' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'read_more_bg_color',
            [
                'label' => __('رنگ پس‌زمینه', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#3a7bd5',
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-read-more' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'read_more_border',
                'label' => __('حاشیه', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .mohtavanegar-read-more',
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'read_more_border_radius',
            [
                'label' => __('گردی گوشه‌ها', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-read-more' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'read_more_box_shadow',
                'label' => __('سایه', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .mohtavanegar-read-more',
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        // Hover State
        $this->start_controls_tab(
            'read_more_hover_tab',
            [
                'label' => __('هاور', 'mohtavanegar'),
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'read_more_hover_color',
            [
                'label' => __('رنگ متن در هاور', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-read-more:hover' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'read_more_bg_hover_color',
            [
                'label' => __('رنگ پس‌زمینه در هاور', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#00d2ff',
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-read-more:hover' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'read_more_hover_border_color',
            [
                'label' => __('رنگ حاشیه در هاور', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-read-more:hover' => 'border-color: {{VALUE}}',
                ],
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'read_more_hover_box_shadow',
                'label' => __('سایه در هاور', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .mohtavanegar-read-more:hover',
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        // Typography
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'read_more_typography',
                'label' => __('تایپوگرافی دکمه', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .mohtavanegar-read-more',
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        // Padding
        $this->add_responsive_control(
            'read_more_padding',
            [
                'label' => __('فاصله داخلی', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-read-more' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_read_more' => 'yes',
                ],
                'separator' => 'before',
            ]
        );

        // Margin
        $this->add_responsive_control(
            'read_more_margin',
            [
                'label' => __('فاصله خارجی', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-read-more' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );
        
        // Hover Animation
        $this->add_control(
            'read_more_hover_animation',
            [
                'label' => __('انیمیشن هاور', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::HOVER_ANIMATION,
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $this->end_controls_section(); // End General Style Section

        // Carousel Style Section
        $this->start_controls_section(
            'carousel_style_section',
            [
                'label' => __('استایل کروسل', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'display_type' => 'carousel',
                ],
            ]
        );
        
        // Arrows Style
        $this->start_controls_tabs('carousel_arrows_style_tabs');

        // Normal State
        $this->start_controls_tab(
            'carousel_arrows_normal_tab',
            [
                'label' => __('عادی', 'mohtavanegar'),
                'condition' => [
                    'show_arrows' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'arrow_color',
            [
                'label' => __('رنگ فلش', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#333333',
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-arrow' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_arrows' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'arrow_bg_color',
            [
                'label' => __('رنگ پس‌زمینه فلش', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(255, 255, 255, 0.9)',
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-arrow' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'show_arrows' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        // Hover State
        $this->start_controls_tab(
            'carousel_arrows_hover_tab',
            [
                'label' => __('هاور', 'mohtavanegar'),
                'condition' => [
                    'show_arrows' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'arrow_hover_color',
            [
                'label' => __('رنگ فلش در هاور', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-arrow:hover' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_arrows' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'arrow_bg_hover_color',
            [
                'label' => __('رنگ پس‌زمینه فلش در هاور', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#1e87f0',
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-arrow:hover' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'show_arrows' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        // Arrow Size
        $this->add_control(
            'arrow_size',
            [
                'label' => __('اندازه فلش (پیکسل)', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 60,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 20,
                ],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-arrow:before' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_arrows' => 'yes',
                ],
            ]
        );

        // Arrow Box Size
        $this->add_control(
            'arrow_box_size',
            [
                'label' => __('اندازه باکس فلش (پیکسل)', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 20,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 40,
                ],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-arrow' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_arrows' => 'yes',
                ],
            ]
        );

        // Dots Style
        $this->add_control(
            'dots_style_heading',
            [
                'label' => __('نقاط ناوبری', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'show_dots' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'dots_color',
            [
                'label' => __('رنگ نقاط', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#cccccc',
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-dots li button' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'show_dots' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'dots_active_color',
            [
                'label' => __('رنگ نقطه فعال', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#1e87f0',
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-dots li.slick-active button' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'show_dots' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'dots_size',
            [
                'label' => __('اندازه نقاط (پیکسل)', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 4,
                        'max' => 20,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 10,
                ],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-dots li button' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_dots' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'dots_spacing',
            [
                'label' => __('فاصله بین نقاط (پیکسل)', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 30,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 5,
                ],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-dots li' => 'margin: 0 {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_dots' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'dots_position',
            [
                'label' => __('موقعیت نقاط', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range' => [
                    'px' => [
                        'min' => -50,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .mohtavanegar-carousel .slick-dots' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_dots' => 'yes',
                ],
            ]
        );

        $this->end_controls_section(); // End Carousel Style Section

        // Responsive Columns Section
        $this->start_controls_section(
            'responsive_columns_section',
            [
                'label' => __('ستون‌های واکنش‌گرا', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'display_type' => ['grid', 'carousel'],
                ],
            ]
        );

        $this->add_responsive_control(
            'columns',
            [
                'label' => __('تعداد ستون‌ها', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '3',
                'tablet_default' => '2',
                'mobile_default' => '1',
                'options' => [
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                    '5' => '5',
                    '6' => '6',
                ],
                'frontend_available' => true,
            ]
        );

        $this->end_controls_section(); // End Responsive Columns Section
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        
        // Optimize query args
        $args = [
            'post_type' => $settings['post_type'],
            'posts_per_page' => $settings['posts_per_page'],
            'post_status' => 'publish',
            'no_found_rows' => true, // Improve performance when pagination is not needed
            'update_post_meta_cache' => false, // Don't cache post meta
            'update_post_term_cache' => false, // Don't cache terms
        ];

        $query = new \WP_Query($args);

        if ($query->have_posts()) {
            // Prepare wrapper classes
            $wrapper_classes = [
                'mohtavanegar-posts-wrapper', 
                'mohtavanegar-posts-' . $settings['display_type']
            ];
            
            // Add grid classes for grid and carousel layouts
            if (in_array($settings['display_type'], ['grid', 'carousel'])) {
                $wrapper_classes[] = 'elementor-grid';
                
                // Get responsive columns
                $columns = isset($settings['columns']) ? $settings['columns'] : 3;
                $columns_tablet = isset($settings['columns_tablet']) ? $settings['columns_tablet'] : 2;
                $columns_mobile = isset($settings['columns_mobile']) ? $settings['columns_mobile'] : 1;
                
                // Add responsive grid classes
                $wrapper_classes[] = 'elementor-grid-' . $columns;
                $wrapper_classes[] = 'elementor-grid-tablet-' . $columns_tablet;
                $wrapper_classes[] = 'elementor-grid-mobile-' . $columns_mobile;
                
                // Add carousel specific classes and data attributes
                if ($settings['display_type'] === 'carousel') {
                    $wrapper_classes[] = 'mohtavanegar-carousel';
                    
                    $this->add_render_attribute('wrapper', [
                        'data-columns' => $columns,
                        'data-columns-tablet' => $columns_tablet,
                        'data-columns-mobile' => $columns_mobile,
                        'data-show-arrows' => $settings['show_arrows'],
                        'data-show-dots' => $settings['show_dots'],
                        'data-autoplay' => $settings['autoplay'],
                        'data-autoplay-speed' => $settings['autoplay_speed'],
                        'data-infinite' => $settings['infinite_loop'],
                        'data-pause-on-hover' => $settings['pause_on_hover'],
                        'data-arrow-style' => $settings['arrow_style']
                    ]);
                }
            }
            
            // Add all wrapper classes at once
            $this->add_render_attribute('wrapper', 'class', $wrapper_classes);
            
            echo '<div ' . $this->get_render_attribute_string('wrapper') . '>';
            
            // Get image size
            $image_size = $settings['image_size'] ?? 'mohtavanegar_grid_300x260';
            
            // Register custom image size if not exists
            if ($image_size === 'mohtavanegar_grid_300x260' && !has_image_size('mohtavanegar_grid_300x260')) {
                add_image_size('mohtavanegar_grid_300x260', 300, 260, true);
            }
            
            if ($settings['display_type'] === 'carousel') {
                echo '<div class="mohtavanegar-carousel">';
                echo '<div class="swiper">';
                echo '<div class="swiper-wrapper">';
            }
            
            while ($query->have_posts()) {
                $query->the_post();
                $post_id = get_the_ID();
                ?>
                <article id="post-<?php echo esc_attr($post_id); ?>" <?php post_class('mohtavanegar-post-item'); ?>>
                    <?php if (has_post_thumbnail()) : ?>
                        <div class="mohtavanegar-post-thumbnail">
                            <a href="<?php the_permalink(); ?>">
                                <?php the_post_thumbnail($image_size, [
                                    'class' => 'mohtavanegar-post-image',
                                    'loading' => 'lazy'
                                ]); ?>
                            </a>
                        </div>
                    <?php endif; ?>

                    <div class="mohtavanegar-post-content">
                        <h3 class="mohtavanegar-post-title">
                            <a href="<?php the_permalink(); ?>">
                                <?php the_title(); ?>
                            </a>
                        </h3>

                        <?php if ('yes' === $settings['show_meta']) : ?>
                            <div class="mohtavanegar-post-meta">
                                <span class="mohtavanegar-post-date"><?php echo get_the_date(); ?></span>
                                <span class="mohtavanegar-post-author"><?php echo esc_html__('نوشته شده توسط ', 'mohtavanegar') . get_the_author(); ?></span>
                            </div>
                        <?php endif; ?>

                        <?php if ('yes' === $settings['show_excerpt']) : ?>
                            <div class="mohtavanegar-post-excerpt">
                                <?php the_excerpt(); ?>
                            </div>
                        <?php endif; ?>

                        <?php if ('yes' === $settings['show_read_more']) : ?>
                            <div class="mohtavanegar-post-read-more">
                                <a href="<?php the_permalink(); ?>" class="mohtavanegar-read-more">
                                    <?php echo esc_html__('ادامه مطلب', 'mohtavanegar'); ?>
                                </a>
                            </div>
                        <?php endif; ?>
                    </div>
                </article>
                <?php
            }
            
            if ($settings['display_type'] === 'carousel') {
                echo '</div>'; // Close swiper-wrapper
                
                // Add pagination if enabled
                if ($settings['show_dots'] === 'yes') {
                    echo '<div class="swiper-pagination"></div>';
                }
                
                // Add navigation arrows if enabled
                if ($settings['show_arrows'] === 'yes') {
                    echo '<div class="swiper-button-prev"></div>';
                    echo '<div class="swiper-button-next"></div>';
                }
                
                echo '</div>'; // Close swiper
                echo '</div>'; // Close mohtavanegar-carousel
            }
            
            echo '</div>';
            
            wp_reset_postdata();
        } else {
            echo '<p>' . esc_html__('هیچ پستی یافت نشد.', 'mohtavanegar') . '</p>';
        }
    }
}
