<?php
if (!defined('ABSPATH')) {
    exit;
}

class Mohtavanegar_QA_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'mohtavanegar_qa';
    }

    public function get_title() {
        return esc_html__('پرسش و پاسخ', 'mohtavanegar');
    }

    public function get_icon() {
        return 'eicon-comments';
    }

    public function get_categories() {
        return ['mohtavanegar'];
    }

    public function get_keywords() {
        return ['qa', 'question', 'answer', 'comment', 'mohtavanegar'];
    }

    public function get_style_depends() {
        wp_register_style(
            'qa-widget-style',
            get_template_directory_uri() . '/assets/css/qa-widget.css',
            array(),
            '1.0.0'
        );
        return ['qa-widget-style'];
    }

    protected function register_controls() {
        // Content Section
        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('تنظیمات محتوا', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'show_form',
            [
                'label' => esc_html__('نمایش فرم ثبت نظر', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('بله', 'mohtavanegar'),
                'label_off' => esc_html__('خیر', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_comments',
            [
                'label' => esc_html__('نمایش لیست نظرات', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('بله', 'mohtavanegar'),
                'label_off' => esc_html__('خیر', 'mohtavanegar'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'comments_per_page',
            [
                'label' => esc_html__('تعداد نظرات در هر صفحه', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 100,
                'step' => 1,
                'default' => 5,
                'condition' => [
                    'show_comments' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'form_title',
            [
                'label' => esc_html__('عنوان فرم', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('ثبت پرسش جدید', 'mohtavanegar'),
                'condition' => [
                    'show_form' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'comments_title',
            [
                'label' => esc_html__('عنوان لیست نظرات', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('پرسش و پاسخ های کاربران', 'mohtavanegar'),
                'condition' => [
                    'show_comments' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

        // Style Section - Form
        $this->start_controls_section(
            'form_style_section',
            [
                'label' => esc_html__('استایل فرم', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_form' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'form_title_color',
            [
                'label' => esc_html__('رنگ عنوان فرم', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .qa-form-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'form_title_typography',
                'label' => esc_html__('تایپوگرافی عنوان فرم', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .qa-form-title',
            ]
        );

        $this->add_control(
            'form_background_color',
            [
                'label' => esc_html__('رنگ پس زمینه فرم', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .qa-form-container' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'form_border',
                'label' => esc_html__('حاشیه فرم', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .qa-form-container',
            ]
        );

        $this->add_control(
            'form_border_radius',
            [
                'label' => esc_html__('گردی گوشه‌های فرم', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .qa-form-container' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'form_padding',
            [
                'label' => esc_html__('فاصله داخلی فرم', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .qa-form-container' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        // Style Section - Comments
        $this->start_controls_section(
            'comments_style_section',
            [
                'label' => esc_html__('استایل نظرات', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_comments' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'comments_title_color',
            [
                'label' => esc_html__('رنگ عنوان لیست نظرات', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .qa-comments-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'comments_title_typography',
                'label' => esc_html__('تایپوگرافی عنوان لیست نظرات', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .qa-comments-title',
            ]
        );

        $this->add_control(
            'comment_background_color',
            [
                'label' => esc_html__('رنگ پس زمینه نظرات', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .qa-comment-item' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'question_color',
            [
                'label' => esc_html__('رنگ متن پرسش', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .qa-question' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'answer_color',
            [
                'label' => esc_html__('رنگ متن پاسخ', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .qa-answer' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'comment_border',
                'label' => esc_html__('حاشیه نظرات', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .qa-comment-item',
            ]
        );

        $this->add_control(
            'comment_border_radius',
            [
                'label' => esc_html__('گردی گوشه‌های نظرات', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .qa-comment-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'comment_padding',
            [
                'label' => esc_html__('فاصله داخلی نظرات', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .qa-comment-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'comment_margin',
            [
                'label' => esc_html__('فاصله بین نظرات', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .qa-comment-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
                    'top' => '0',
                    'right' => '0',
                    'bottom' => '15',
                    'left' => '0',
                    'unit' => 'px',
                    'isLinked' => false,
                ],
            ]
        );

        $this->end_controls_section();

        // Style Section - Button
        $this->start_controls_section(
            'button_style_section',
            [
                'label' => esc_html__('استایل دکمه', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_form' => 'yes',
                ],
            ]
        );

        $this->start_controls_tabs('button_style_tabs');

        $this->start_controls_tab(
            'button_normal_tab',
            [
                'label' => esc_html__('عادی', 'mohtavanegar'),
            ]
        );

        $this->add_control(
            'button_text_color',
            [
                'label' => esc_html__('رنگ متن دکمه', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .qa-submit-button' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_background_color',
            [
                'label' => esc_html__('رنگ پس زمینه دکمه', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .qa-submit-button' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'button_hover_tab',
            [
                'label' => esc_html__('هاور', 'mohtavanegar'),
            ]
        );

        $this->add_control(
            'button_hover_text_color',
            [
                'label' => esc_html__('رنگ متن دکمه (هاور)', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .qa-submit-button:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_hover_background_color',
            [
                'label' => esc_html__('رنگ پس زمینه دکمه (هاور)', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .qa-submit-button:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'button_border',
                'label' => esc_html__('حاشیه دکمه', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .qa-submit-button',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'button_border_radius',
            [
                'label' => esc_html__('گردی گوشه‌های دکمه', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .qa-submit-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'button_padding',
            [
                'label' => esc_html__('فاصله داخلی دکمه', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .qa-submit-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $show_form = $settings['show_form'] === 'yes';
        $show_comments = $settings['show_comments'] === 'yes';
        $form_title = $settings['form_title'];
        $comments_title = $settings['comments_title'];
        $comments_per_page = $settings['comments_per_page'];
        
        // Enqueue the script for form submission
        wp_enqueue_script(
            'qa-frontend-js',
            get_template_directory_uri() . '/js/qa-frontend.js',
            array('jquery'),
            '1.0.0',
            true
        );
        
        wp_localize_script('qa-frontend-js', 'qaFrontendData', array(
            'ajaxUrl' => admin_url('admin-ajax.php'),
            'nonce'   => wp_create_nonce('qa_submit_nonce'),
        ));
        
        ?>
        <div class="mohtavanegar-qa-widget">
            <?php if ($show_form) : ?>
                <div class="qa-form-section">
                    <h3 class="qa-form-title"><?php echo esc_html($form_title); ?></h3>
                    
                    <div class="qa-message" id="qa-form-message"></div>
                    
                    <div class="qa-form-container">
                        <form id="qa-submission-form">
                            <div class="qa-form-group">
                                <label for="qa-name"><?php echo esc_html__('نام', 'mohtavanegar'); ?></label>
                                <input type="text" id="qa-name" name="qa-name" class="qa-form-control" required>
                            </div>
                            
                            <div class="qa-form-group">
                                <label for="qa-email"><?php echo esc_html__('ایمیل', 'mohtavanegar'); ?> <small>(اختیاری)</small></label>
                                <input type="email" id="qa-email" name="qa-email" class="qa-form-control">
                            </div>
                            
                            <div class="qa-form-group">
                                <label for="qa-mobile"><?php echo esc_html__('موبایل', 'mohtavanegar'); ?> <small>(اختیاری)</small></label>
                                <input type="tel" id="qa-mobile" name="qa-mobile" class="qa-form-control" placeholder="09xxxxxxxxx">
                            </div>
                            
                            <div class="qa-form-group">
                                <label for="qa-question"><?php echo esc_html__('پرسش شما', 'mohtavanegar'); ?></label>
                                <textarea id="qa-question" name="qa-question" class="qa-form-control" rows="4" required></textarea>
                            </div>
                            
                            <div class="qa-form-group">
                                <button type="submit" class="qa-submit-button"><?php echo esc_html__('ارسال پرسش', 'mohtavanegar'); ?></button>
                            </div>
                        </form>
                    </div>
                </div>
            <?php endif; ?>
            
            <?php if ($show_comments) : ?>
                <div class="qa-comments-section">
                    <h3 class="qa-comments-title"><?php echo esc_html($comments_title); ?></h3>
                    
                    <?php
                    $args = array(
                        'post_type'      => 'qa_comment',
                        'post_status'    => 'publish',
                        'posts_per_page' => $comments_per_page,
                        'orderby'        => 'date',
                        'order'          => 'DESC',
                    );
                    
                    $comments = new \WP_Query($args);
                    
                    if ($comments->have_posts()) :
                        // Enqueue the accordion script
                        wp_enqueue_script(
                            'qa-accordion-js',
                            get_template_directory_uri() . '/js/qa-accordion.js',
                            array('jquery'),
                            '1.0.0',
                            true
                        );
                        
                        echo '<div class="qa-accordion">';
                        
                        while ($comments->have_posts()) : $comments->the_post();
                            $name = get_post_meta(get_the_ID(), '_qa_name', true);
                            $question = get_the_title();
                            $answer = get_post_meta(get_the_ID(), '_qa_answer', true);
                            $date = get_the_date('Y-m-d');
                            ?>
                            <div class="qa-accordion-item">
                                <div class="qa-accordion-header">
                                    <div class="qa-accordion-title"><?php echo esc_html($question); ?></div>
                                    <div class="qa-accordion-icon"></div>
                                </div>
                                
                                <div class="qa-accordion-content">
                                    
                                    <div class="qa-accordion-question">
                                        <strong><?php echo esc_html__('پرسش:', 'mohtavanegar'); ?></strong>
                                        <?php echo esc_html($question); ?>
                                    </div>
                                    
                                    <?php if (!empty($answer)) : ?>
                                        <div class="qa-accordion-answer">
                                            <strong><?php echo esc_html__('پاسخ:', 'mohtavanegar'); ?></strong>
                                            <div class="qa-answer-content">
                                                <?php echo wpautop(wp_kses_post($answer)); ?>
                                            </div>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                            <?php
                        endwhile;
                        
                        echo '</div>';
                        
                        wp_reset_postdata();
                    else :
                        echo '<div class="qa-no-comments">' . esc_html__('هیچ پرسش و پاسخی یافت نشد.', 'mohtavanegar') . '</div>';
                    endif;
                    ?>
                </div>
            <?php endif; ?>
        </div>
        <?php
    }
}
