<?php
if (!defined('ABSPATH')) {
    exit;
}

class Mohtavanegar_Services_List_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'mohtavanegar_services_list';
    }

    public function get_title() {
        return esc_html__('لیست خدمات', 'mohtavanegar');
    }

    public function get_icon() {
        return 'eicon-bullet-list';
    }

    public function get_categories() {
        return ['mohtavanegar'];
    }

    public function get_keywords() {
        return ['services', 'list', 'mohtavanegar'];
    }

    protected function register_controls() {
        // Content Section
        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('تنظیمات محتوا', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'posts_per_page',
            [
                'label' => esc_html__('تعداد خدمات در هر صفحه', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 100,
                'step' => 1,
                'default' => 6,
            ]
        );

        $this->add_control(
            'columns',
            [
                'label' => esc_html__('تعداد ستون‌ها', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '3',
                'options' => [
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                ],
            ]
        );

        $this->add_control(
            'category',
            [
                'label' => esc_html__('دسته‌بندی', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => $this->get_services_categories(),
                'multiple' => true,
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label' => esc_html__('مرتب‌سازی بر اساس', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date' => esc_html__('تاریخ', 'mohtavanegar'),
                    'title' => esc_html__('عنوان', 'mohtavanegar'),
                    'menu_order' => esc_html__('ترتیب منو', 'mohtavanegar'),
                ],
            ]
        );

        $this->add_control(
            'order',
            [
                'label' => esc_html__('ترتیب', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'DESC',
                'options' => [
                    'ASC' => esc_html__('صعودی', 'mohtavanegar'),
                    'DESC' => esc_html__('نزولی', 'mohtavanegar'),
                ],
            ]
        );

        $this->end_controls_section();

        // Style Section
        $this->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('تنظیمات ظاهری', 'mohtavanegar'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('رنگ عنوان', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => esc_html__('تایپوگرافی عنوان', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .service-title',
            ]
        );

        $this->add_control(
            'price_color',
            [
                'label' => esc_html__('رنگ قیمت', 'mohtavanegar'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-price' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'price_typography',
                'label' => esc_html__('تایپوگرافی قیمت', 'mohtavanegar'),
                'selector' => '{{WRAPPER}} .service-price',
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();

        $args = array(
            'post_type' => 'services',
            'posts_per_page' => $settings['posts_per_page'],
            'orderby' => $settings['orderby'],
            'order' => $settings['order'],
        );

        if (!empty($settings['category'])) {
            $args['tax_query'] = array(
                array(
                    'taxonomy' => 'services_category',
                    'field' => 'term_id',
                    'terms' => $settings['category'],
                ),
            );
        }

        $services = new \WP_Query($args);

        if ($services->have_posts()) :
            echo '<div class="services-grid columns-' . esc_attr($settings['columns']) . '">';
            
            while ($services->have_posts()) : $services->the_post();
                $price = get_post_meta(get_the_ID(), '_service_price', true);
                $duration = get_post_meta(get_the_ID(), '_service_duration', true);
                $icon = get_post_meta(get_the_ID(), '_service_icon', true);
                ?>
                <div class="service-item">
                    <?php if ($icon) : ?>
                        <div class="service-icon">
                            <i class="<?php echo esc_attr($icon); ?>"></i>
                        </div>
                    <?php endif; ?>
                    
                    <h3 class="service-title">
                        <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                    </h3>
                    
                    <?php if ($price) : ?>
                        <div class="service-price"><?php echo esc_html($price); ?></div>
                    <?php endif; ?>
                    
                    <?php if ($duration) : ?>
                        <div class="service-duration"><?php echo esc_html($duration); ?></div>
                    <?php endif; ?>
                    
                    <div class="service-excerpt">
                        <?php the_excerpt(); ?>
                    </div>
                    
                    <a href="<?php the_permalink(); ?>" class="service-link">
                        <?php esc_html_e('مشاهده جزئیات', 'mohtavanegar'); ?>
                    </a>
                </div>
                <?php
            endwhile;
            
            echo '</div>';
            
            wp_reset_postdata();
        else :
            echo '<p>' . esc_html__('هیچ خدمتی یافت نشد.', 'mohtavanegar') . '</p>';
        endif;
    }

    private function get_services_categories() {
        $categories = get_terms(array(
            'taxonomy' => 'services_category',
            'hide_empty' => true,
        ));

        $options = array();
        if (!is_wp_error($categories)) {
            foreach ($categories as $category) {
                $options[$category->term_id] = $category->name;
            }
        }

        return $options;
    }
} 